package com.landray.kmss.sys.attachment.actions;

import java.util.Map;
import com.landray.kmss.web.config.IActionConfig;
import com.landray.kmss.web.config.ForwardConfig;
import com.landray.kmss.util.KmssReturnPage;
import java.util.List;
import java.io.OutputStream;
import com.landray.kmss.sys.attachment.util.AttImageUtils;
import com.landray.kmss.util.FileMimeTypeUtil;
import org.apache.commons.io.FilenameUtils;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.sys.attachment.util.SysAttPicUtils;
import com.landray.kmss.util.DbUtils;
import com.landray.kmss.util.KmssMessage;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.util.KmssMessages;
import com.landray.kmss.web.action.ActionForward;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import com.landray.kmss.common.actions.BaseAction;

public class SysAttPicAction extends BaseAction
{
    protected ISysAttMainCoreInnerService sysAttMainService;
    
    protected ISysAttMainCoreInnerService getServiceImp(final HttpServletRequest request) {
        if (this.sysAttMainService == null) {
            this.sysAttMainService = (ISysAttMainCoreInnerService)this.getBean("sysAttMainService");
        }
        return this.sysAttMainService;
    }
    
    public ActionForward view(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final KmssMessages messages = new KmssMessages();
        OutputStream out = null;
        try {
            final String fdId = request.getParameter("fdId");
            final String timestamp = request.getParameter("t");
            final String key = request.getParameter("k");
            if (StringUtil.isNull(timestamp) || StringUtil.isNull(key)) {
                messages.addError(new KmssMessage("sys-attachment:sysAttMain.error.downloadPic"));
                return this.viewAttError(mapping, request, response, messages);
            }
            if (DbUtils.getDbTimeMillis() - Long.parseLong(timestamp) > 600000L) {
                messages.addError(new KmssMessage("sys-attachment:sysAttMain.error.downloadPic"));
                return this.viewAttError(mapping, request, response, messages);
            }
            if (!SysAttPicUtils.verify(String.valueOf(timestamp) + fdId, key)) {
                messages.addError(new KmssMessage("sys-attachment:sysAttMain.error.downloadPic"));
                return this.viewAttError(mapping, request, response, messages);
            }
            final List<SysAttMain> sysAttMains = this.getAttMains(request);
            if (sysAttMains == null || sysAttMains.isEmpty()) {
                messages.addError(new KmssMessage("sys-attachment:sysAttMain.error.downloadPic"));
                return this.viewAttError(mapping, request, response, messages);
            }
            final SysAttMain sysAttMain = sysAttMains.get(0);
            if (!"pic".equals(sysAttMain.getFdAttType()) && !SysAttPicUtils.isImageType(FilenameUtils.getExtension(sysAttMain.getFdFileName()))) {
                messages.addError(new KmssMessage("sys-attachment:sysAttMain.error.downloadPic"));
                return this.viewAttError(mapping, request, response, messages);
            }
            final int fileSize = sysAttMain.getFdSize().intValue();
            final String filename = new String(sysAttMain.getFdFileName().getBytes("UTF-8"), "ISO8859-1");
            String fileContentType = FileMimeTypeUtil.getContentType(filename);
            if (StringUtil.isNull(fileContentType)) {
                fileContentType = sysAttMain.getFdContentType();
            }
            response.reset();
            if (AttImageUtils.cacheConsulation(request, response, fileContentType, filename)) {
                return null;
            }
            response.setContentLength(fileSize);
            response.setContentType(fileContentType);
            response.setHeader("Pragma", "public");
            response.setHeader("Content-Disposition", "filename=\"" + filename + "\"");
            out = (OutputStream)response.getOutputStream();
            this.getServiceImp(request).findData(sysAttMain.getFdId(), out);
            return null;
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        finally {
            if (out != null) {
                out.close();
                out = null;
            }
        }
        if (messages.hasError()) {
            return this.viewAttError(mapping, request, response, messages);
        }
        return null;
    }
    
    private List<SysAttMain> getAttMains(final HttpServletRequest request) throws Exception {
        final String fdId = request.getParameter("fdId");
        List<SysAttMain> sysAttMains = null;
        if (fdId != null && fdId.trim().length() > 0) {
            final String[] fdIds = fdId.split(";");
            sysAttMains = this.getServiceImp(request).findModelsByIds(fdIds);
        }
        return sysAttMains;
    }
    
    private ActionForward viewAttError(final ActionMapping mapping, final HttpServletRequest request, final HttpServletResponse response, final KmssMessages messages) {
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        return mapping.findForward("failure");
    }
}
